@@ -136,8 +136,14 @@ pub fn parse_length(value: &str) -> std::time::Duration {
     }))
 }
 
-/// Parse a video upload data in the format `[Premiered ]<MONTH_NAME> <DAY>, <YEAR>`
+/// Parse a video upload data in the format `[Premiered |Premires ]<MONTH_NAME> <DAY>, <YEAR>`
 pub fn parse_date(value: &str) -> Option<chrono::NaiveDate> {
-    let value = value.strip_prefix("Premiered ").unwrap_or(value);
+    const PREFIXES: &[&str] = &["Premiered ", "Premieres "];
+
+    let value = PREFIXES
+        .iter()
+        .find_map(|x| value.strip_prefix(x))
+        .unwrap_or(value);
+
     chrono::NaiveDate::parse_from_str(value, "%b %e, %Y").ok()
 }
